
# Other implementations of variant and optional

These are some other implementations of `variant` and/or `optional` types.
They are not necessarily compatible with this implementation. This is an
incomplete list.

* [Boost Variant](http://www.boost.org/doc/libs/1_59_0/doc/html/variant.html) and [Boost Optional](http://www.boost.org/doc/libs/1_59_0/libs/optional/doc/html/index.html)
* [Eggs Variant](http://eggs-cpp.github.io/variant/) by [Agustín Bergé](http://talesofcpp.fusionfenix.com/)
* [anthonyw/variant](https://bitbucket.org/anthonyw/variant) (implementation of P0110R0)
* [JasonL9000/cppcon14](https://github.com/JasonL9000/cppcon14)
* [tomilov/variant](https://github.com/tomilov/variant)
* [akrzemi1/Optional](https://github.com/akrzemi1/Optional)
* [mpark/variant](https://github.com/mpark/variant)

